@@ -1,7 +1,5 @@
 /* cleansess.c - Clean up the pty and frob utmp/wtmp accordingly after logout
-  Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004,
-  2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software
-  Foundation, Inc.
+  Copyright (C) 1996-2025 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -57,7 +55,7 @@ cleanup_session (char *tty, int pty_fd)
   if (strncmp (tty, PATH_TTY_PFX, sizeof PATH_TTY_PFX - 1) == 0)
     line = tty + sizeof PATH_TTY_PFX - 1;
   else
-# endif /* PATH_TTY_PFX */
+# endif/* PATH_TTY_PFX */
     line = tty;
 
   if (logout (line))
