@@ -1,7 +1,5 @@
 /*
-  Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-  2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014,
-  2015 Free Software Foundation, Inc.
+  Copyright (C) 1995-2025 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -84,7 +82,7 @@
 
 #include "tftpsubs.h"
 
-#include <unused-parameter.h>
+#include <attribute.h>
 #include <xalloc.h>
 #include <argp.h>
 #include <progname.h>
@@ -109,7 +107,7 @@ static char *user;
 
 /* Some systems define PKTSIZE in <arpa/tftp.h>.  */
 #ifndef PKTSIZE
-#define PKTSIZE	SEGSIZE+4
+# define PKTSIZE	SEGSIZE+4
 #endif
 static char buf[PKTSIZE];
 static char ackbuf[PKTSIZE];
@@ -137,34 +135,33 @@ static int logging;
 static const char *errtomsg (int);
 static void nak (int);
 static const char *verifyhost (struct sockaddr_storage *, socklen_t);
-
 
 
+
 static struct argp_option options[] = {
 #define GRP 0
-  { "logging", 'l', NULL, 0,
-    "enable logging", GRP+1},
-  { "nonexistent", 'n', NULL, 0,
-    "supress negative acknowledgement of requests for "
-    "nonexistent relative filenames", GRP+1},
+  {"logging", 'l', NULL, 0,
+   "enable logging", GRP + 1},
+  {"nonexistent", 'n', NULL, 0,
+   "supress negative acknowledgement of requests for "
+   "nonexistent relative filenames", GRP + 1},
 #undef GRP
 #define GRP 10
-  { NULL, 0, NULL, 0, "", GRP},
-  { "group", 'g', "GRP", 0,
-    "set explicit group of process owner, used with '-s'", GRP+1},
-  { "secure-dir", 's', "DIR", 0,
-    "change root directory to DIR before searching and "
-    "serving content", GRP+1},
-  { "user", 'u', "USR", 0,
-    "set name of process owner, used with '-s' and "
-    "defaults to 'nobody'", GRP+1},
+  {NULL, 0, NULL, 0, "", GRP},
+  {"group", 'g', "GRP", 0,
+   "set explicit group of process owner, used with '-s'", GRP + 1},
+  {"secure-dir", 's', "DIR", 0,
+   "change root directory to DIR before searching and "
+   "serving content", GRP + 1},
+  {"user", 'u', "USR", 0,
+   "set name of process owner, used with '-s' and "
+   "defaults to 'nobody'", GRP + 1},
 #undef GRP
-  { NULL, 0, NULL, 0, NULL, 0}
+  {NULL, 0, NULL, 0, NULL, 0}
 };
 
 static error_t
-parse_opt (int key, char *arg,
-	   struct argp_state *state _GL_UNUSED_PARAMETER)
+parse_opt (int key, char *arg, struct argp_state *state MAYBE_UNUSED)
 {
   switch (key)
     {
@@ -197,21 +194,20 @@ parse_opt (int key, char *arg,
   return 0;
 }
 
-static struct argp argp =
-  {
-    options,
-    parse_opt,
-    "directory...",
-    "Trivial File Transfer Protocol server",
-    NULL, NULL, NULL
-  };
-
+static struct argp argp = {
+  options,
+  parse_opt,
+  "directory...",
+  "Trivial File Transfer Protocol server",
+  NULL, NULL, NULL
+};
 
+
 int
 main (int argc, char *argv[])
 {
   int index;
-  register struct tftphdr *tp;
+  struct tftphdr *tp;
   int on, n;
   struct sockaddr_storage sin;
 
@@ -221,7 +217,7 @@ main (int argc, char *argv[])
   iu_argp_init ("tftpd", default_program_authors);
   argp_parse (&argp, argc, argv, 0, &index, NULL);
 
-  openlog ("tftpd", LOG_PID, LOG_FTP);
+  openlog ("tftpd", LOG_NDELAY | LOG_PID, LOG_FTP);
 
   if (index < argc)
     {
@@ -344,7 +340,7 @@ main (int argc, char *argv[])
       struct group *grp = NULL;
 
       /* Ignore user and group setting for non-root invocations.  */
-      if (!getuid())
+      if (!getuid ())
 	{
 	  pwd = getpwnam (user);
 	  if (!pwd)
@@ -416,7 +412,7 @@ main (int argc, char *argv[])
 
 struct formats;
 int validate_access (char **, int);
-void send_file (struct formats *);
+void tftpd_sendfile (struct formats *);
 void recvfile (struct formats *);
 
 struct formats
@@ -426,12 +422,11 @@ struct formats
   void (*f_send) (struct formats *);
   void (*f_recv) (struct formats *);
   int f_convert;
-} formats[] =
-  {
-    {"netascii", validate_access, send_file, recvfile, 1},
-    {"octet", validate_access, send_file, recvfile, 0},
-    {0, NULL, NULL, NULL, 0}
-  };
+} formats[] = {
+  {"netascii", validate_access, tftpd_sendfile, recvfile, 1},
+  {"octet", validate_access, tftpd_sendfile, recvfile, 0},
+  {0, NULL, NULL, NULL, 0}
+};
 
 /*
  * Handle initial connection protocol.
@@ -439,9 +434,9 @@ struct formats
 void
 tftp (struct tftphdr *tp, int size)
 {
-  register char *cp;
+  char *cp;
   int first = 1, ecode;
-  register struct formats *pf;
+  struct formats *pf;
   char *filename, *mode;
 
 #if HAVE_STRUCT_TFTPHDR_TH_U
@@ -635,7 +630,7 @@ int timeout;
 sigjmp_buf timeoutbuf;
 
 void
-timer (int sig _GL_UNUSED_PARAMETER)
+timer (int sig MAYBE_UNUSED)
 {
 
   timeout += rexmtval;
@@ -648,11 +643,11 @@ timer (int sig _GL_UNUSED_PARAMETER)
  * Send the requested file.
  */
 void
-send_file (struct formats *pf)
+tftpd_sendfile (struct formats *pf)
 {
   struct tftphdr *dp, *r_init (void);
-  register struct tftphdr *ap;	/* ack packet */
-  register int size, n;
+  struct tftphdr *ap;		/* ack packet */
+  int size, n;
   volatile int block;
 
   signal (SIGALRM, timer);
@@ -674,7 +669,7 @@ send_file (struct formats *pf)
 
     send_data:
       if (sendto (peer, (const char *) dp, size + 4, 0,
-		 (struct sockaddr *) &from, fromlen) != size + 4)
+		  (struct sockaddr *) &from, fromlen) != size + 4)
 	{
 	  syslog (LOG_ERR, "tftpd: write: %m\n");
 	  goto abort;
@@ -702,7 +697,8 @@ send_file (struct formats *pf)
 		break;
 	      /* Re-synchronize with the other side */
 	      synchnet (peer);
-	      if ((unsigned short) ap->th_block == (unsigned short) (block - 1))
+	      if ((unsigned short) ap->th_block ==
+		  (unsigned short) (block - 1))
 		goto send_data;
 	    }
 
@@ -715,7 +711,7 @@ abort:
 }
 
 void
-justquit (int sig _GL_UNUSED_PARAMETER)
+justquit (int sig MAYBE_UNUSED)
 {
   exit (EXIT_SUCCESS);
 }
@@ -728,8 +724,8 @@ void
 recvfile (struct formats *pf)
 {
   struct tftphdr *dp, *w_init (void);
-  register struct tftphdr *ap;	/* ack buffer */
-  register int n, size;
+  struct tftphdr *ap;		/* ack buffer */
+  int n, size;
   volatile int block;
 
   signal (SIGALRM, timer);
@@ -744,7 +740,8 @@ recvfile (struct formats *pf)
       block++;
       sigsetjmp (timeoutbuf, SIGALRM);
     send_ack:
-      if (sendto (peer, ackbuf, 4, 0, (struct sockaddr *) &from, fromlen) != 4)
+      if (sendto (peer, ackbuf, 4, 0, (struct sockaddr *) &from, fromlen) !=
+	  4)
 	{
 	  syslog (LOG_ERR, "tftpd: write: %m\n");
 	  goto abort;
@@ -813,24 +810,23 @@ struct errmsg
 {
   int e_code;
   const char *e_msg;
-} errmsgs[] =
-  {
-    {EUNDEF, "Undefined error code"},
-    {ENOTFOUND, "File not found"},
-    {EACCESS, "Access violation"},
-    {ENOSPACE, "Disk full or allocation exceeded"},
-    {EBADOP, "Illegal TFTP operation"},
-    {EBADID, "Unknown transfer ID"},
-    {EEXISTS, "File already exists"},
-    {ENOUSER, "No such user"},
-    {-1, 0}
-  };
+} errmsgs[] = {
+  {EUNDEF, "Undefined error code"},
+  {ENOTFOUND, "File not found"},
+  {EACCESS, "Access violation"},
+  {ENOSPACE, "Disk full or allocation exceeded"},
+  {EBADOP, "Illegal TFTP operation"},
+  {EBADID, "Unknown transfer ID"},
+  {EEXISTS, "File already exists"},
+  {ENOUSER, "No such user"},
+  {-1, 0}
+};
 
 static const char *
 errtomsg (int error)
 {
   static char buf[20];
-  register struct errmsg *pe;
+  struct errmsg *pe;
   if (error == 0)
     return "success";
   for (pe = errmsgs; pe->e_code >= 0; pe++)
@@ -849,9 +845,9 @@ errtomsg (int error)
 static void
 nak (int error)
 {
-  register struct tftphdr *tp;
+  struct tftphdr *tp;
   int length;
-  register struct errmsg *pe;
+  struct errmsg *pe;
 
   tp = (struct tftphdr *) buf;
   tp->th_opcode = htons ((unsigned short) ERROR);
@@ -864,11 +860,12 @@ nak (int error)
       pe->e_msg = strerror (error - 100);
       tp->th_code = EUNDEF;	/* set 'undef' errorcode */
     }
-  strcpy (tp->th_msg, pe->e_msg);
   length = strlen (pe->e_msg);
+  memcpy (tp->th_msg, pe->e_msg, length);
   tp->th_msg[length] = '\0';
   length += 5;
-  if (sendto (peer, buf, length, 0, (struct sockaddr *) &from, fromlen) != length)
+  if (sendto (peer, buf, length, 0, (struct sockaddr *) &from, fromlen) !=
+      length)
     syslog (LOG_ERR, "nak: %m\n");
 }
 
@@ -884,7 +881,7 @@ verifyhost (struct sockaddr_storage *fromp, socklen_t frlen)
     return host;
   else
     {
-      syslog (LOG_ERR, "getnameinfo: %s\n", gai_strerror(rc));
+      syslog (LOG_ERR, "getnameinfo: %s\n", gai_strerror (rc));
       return "0.0.0.0";
     }
 }
