@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1996-2022 Free Software Foundation, Inc.
+  Copyright (C) 1996-2025 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -33,7 +33,7 @@ struct request_table
 static table_t *table;
 
 static void
-table_delete (table_t * ptr)
+table_delete (table_t *ptr)
 {
   table_t *t;
 
@@ -51,7 +51,7 @@ table_delete (table_t * ptr)
    Evil) */
 
 static CTL_MSG *
-lookup_request (CTL_MSG * request,
+lookup_request (CTL_MSG *request,
 		int (*comp) (table_t *, CTL_MSG *, time_t *))
 {
   table_t *ptr;
@@ -90,8 +90,7 @@ lookup_request (CTL_MSG * request,
 }
 
 static int
-fuzzy_comp (table_t * ptr, CTL_MSG * request,
-	    time_t * unused MAYBE_UNUSED)
+fuzzy_comp (table_t *ptr, CTL_MSG *request, time_t *unused MAYBE_UNUSED)
 {
   if (ptr->request.type == LEAVE_INVITE
       && strcmp (request->l_name, ptr->request.r_name) == 0
@@ -103,13 +102,13 @@ fuzzy_comp (table_t * ptr, CTL_MSG * request,
 /* Look in the table for an invitation that matches the current
    request looking for an invitation */
 CTL_MSG *
-find_match (CTL_MSG * request)
+find_match (CTL_MSG *request)
 {
   return lookup_request (request, fuzzy_comp);
 }
 
 static int
-exact_comp (table_t * ptr, CTL_MSG * request, time_t * now)
+exact_comp (table_t *ptr, CTL_MSG *request, time_t *now)
 {
   if (request->type == ptr->request.type
       && request->pid == ptr->request.pid
@@ -126,7 +125,7 @@ exact_comp (table_t * ptr, CTL_MSG * request, time_t * now)
    one as find_match does */
 
 CTL_MSG *
-find_request (CTL_MSG * request)
+find_request (CTL_MSG *request)
 {
   return lookup_request (request, exact_comp);
 }
@@ -147,7 +146,7 @@ new_id (void)
 }
 
 int
-insert_table (CTL_MSG * request, CTL_RESPONSE * response)
+insert_table (CTL_MSG *request, CTL_RESPONSE *response)
 {
   table_t *ptr;
 
